@@ -1,12 +1,14 @@
-__version__ = "1.0.4"
+__version__ = "1.0.7"
 
+import asyncio
 from concurrent.futures import ThreadPoolExecutor
 
 from aioreq import http
 from aioreq.http import *
 
 try:
-    import uvloop
+    import uvloop  # type: ignore
+
     asyncio.set_event_loop_policy(uvloop.EventLoopPolicy())
 except ImportError:
     ...
