@@ -40,6 +40,8 @@ log_format_mapper = {
     "$message": "%(message)s",
 }
 
+DEFAULT_HEADERS = {"user-agent": "python/aioreq", "Accept": "*/*"}
+
 LOGGER_NAME = parser.get("Logging", "logger_name")
 
 MAIN_LOGGER_LEVEL = parser.get("Logging", "logger_level")
@@ -87,10 +89,10 @@ def _trace(message, *args, **kwargs):
 main_logger = logging.getLogger(LOGGER_NAME)
 main_logger.trace = _trace  # type: ignore
 main_logger.propagate = False
-main_logger.setLevel(MAIN_LOGGER_LEVEL)
+main_logger.setLevel(MAIN_LOGGER_LEVEL)  # type: ignore
 
 handler = logging.StreamHandler()
-handler.setLevel(STREAM_HANDLER_LEVEL)
+handler.setLevel(STREAM_HANDLER_LEVEL)  # type: ignore
 
 formatter = logging.Formatter(FORMAT)
 
